# -*- mode: makefile; tab-width: 8; -*-

TARGET		= quasar
TEMPLATE	= app

CONFIG		= qt warn_on
#CONFIG		= qt warn_on debug

# for native compilation with ccache:
#TMAKE_CC	= ccache gcc
#TMAKE_CXX	= ccache g++
#TMAKE_LINK	= ccache g++

# for native compilation with pdaxii13's zgcc:
#TMAKE_CC	= gcc
#TMAKE_CXX	= g++
#TMAKE_LINK	= g++

# for pdaXii13 cross compiler:
TMAKE_CC	= ccache armv5tel-cacko-linux-gcc
TMAKE_CXX	= ccache armv5tel-cacko-linux-g++
TMAKE_LINK	= ccache armv5tel-cacko-linux-g++

SQLITE_FLAGS = -DSQLITE_OMIT_UTF16 -DSQLITE_OMIT_AUTHORIZATION -DSQLITE_OMIT_PROGRESS_CALLBACK -DSQLITE_OMIT_SHARED_CACHE -DSQLITE_OMIT_LOAD_EXTENSION -DSQLITE_DEFAULT_TEMP_CACHE_SIZE=1000 -DTHREADSAFE=0 -DSQLITE_ENABLE_MEMORY_MANAGEMENT

TMAKE_CFLAGS	= $$TMAKE_CFLAGS $$SQLITE_FLAGS -DQUASAR -O3
TMAKE_CXXFLAGS  = $$TMAKE_CXXFLAGS $$SQLITE_FLAGS -DQUASAR -O3

LIBS		= -liconv -lz -lstdc++

INCLUDEPATH	= \
		. \
		compat \
		config \
		tkmix \
		tag/taglib \
		tag/taglib/taglib \
		tag/taglib/taglib/ape \
		tag/taglib/taglib/flac \
		tag/taglib/taglib/mpc \
		tag/taglib/taglib/mpeg \
		tag/taglib/taglib/mpeg/id3v1 \
		tag/taglib/taglib/mpeg/id3v2 \
		tag/taglib/taglib/mpeg/id3v2/frames \
		tag/taglib/taglib/ogg \
		tag/taglib/taglib/ogg/flac \
		tag/taglib/taglib/ogg/vorbis \
		tag/taglib/taglib/toolkit \
		tag/taglib_addons \
		tag/taglib_addons/aac \
		tag/taglib_addons/audible \
		tag/taglib_addons/m4a \
		tag/taglib_addons/rmff \
		tag/taglib_addons/speex \
		tag/taglib_addons/trueaudio \
		tag/taglib_addons/wav \
		tag/taglib_addons/wavpack \
		tag/taglib_addons/wma \
		kmdcodec \		
		sqlite_source
		
HEADERS		= \
		configuration.h \
		configurationdialog.h \
		media.h \
		mediaidentifier.h \
		mediadatabase.h \
		mediainfodialog.h \
		mplayer.h \
		quasar.h \
		skinpanel.h \
		skinnedbutton.h \
		skinnedlabel.h \
		skinnedtimelabel.h \
		skin.h \
		skinmanager.h \
		operationpanel.h \
		toolpanel.h \
		coverartprovider.h \
		coverart.h \
		playinfo.h \
		imagefx.h \
		videoplaybackwindow.h \
		playlist.h \
		playlistmanager.h \
		playlistoverview.h \
		playlisttoolpanel.h \
		seekbar.h \
		signalhandler.h \
		aboutdialog.h \
		keynames.h \
		action.h \
		textviewdialog.h \
		compat/config.h \
		compat/resource.h \
		config/generalconfig.h \
		config/mplayerconfig.h \
		config/formatsconfig.h \
		config/hotkeyconfig.h \
		config/identifykeydialog.h \
		config/uiconfig.h \
		config/coverartconfig.h \
		tkmix/qtkfiledialog.h \
		system_volume.h \
		externalservices.h

SOURCES		= \
		configuration.cpp \
		configurationdialog.cpp \
		main.cpp \
		debug.cpp \
		media.cpp \
		mediaidentifier.cpp \
		mediadatabase.cpp \
		mediainfodialog.cpp \
		mplayer.cpp \
		quasar.cpp \
		skinpanel.cpp \		
		skinnedbutton.cpp \
		skinnedlabel.cpp \
		skinnedtimelabel.cpp \
		skin.cpp \
		skinmanager.cpp \
		operationpanel.cpp \
		toolpanel.cpp \	
		coverartprovider.cpp \
		coverart.cpp \		
		playinfo.cpp \
		imagefx.cpp \
		videoplaybackwindow.cpp \
		playlist.cpp \
		playlistmanager.cpp \
		playlistoverview.cpp \
		playlisttoolpanel.cpp \
		seekbar.cpp \
		signalhandler.cpp \
		aboutdialog.cpp \
		keynames.cpp \
		action.cpp \
		textviewdialog.cpp \
		compat/config.cpp \
		compat/resource.cpp \
		config/generalconfig.cpp \
		config/mplayerconfig.cpp \
		config/formatsconfig.cpp \
		config/hotkeyconfig.cpp \
		config/identifykeydialog.cpp \
		config/uiconfig.cpp \
		config/coverartconfig.cpp \
		tkmix/qtkfiledialog.cpp \
		system_volume.cpp \
		externalservices.cpp \
		tag/taglib/taglib/ape/apefooter.cpp \
		tag/taglib/taglib/ape/apeitem.cpp \
		tag/taglib/taglib/ape/apetag.cpp \
		tag/taglib/taglib/audioproperties.cpp \
		tag/taglib/taglib/fileref.cpp \
		tag/taglib/taglib/flac/flacfile.cpp \
		tag/taglib/taglib/flac/flacproperties.cpp \
		tag/taglib/taglib/mpc/mpcfile.cpp \
		tag/taglib/taglib/mpc/mpcproperties.cpp \
		tag/taglib/taglib/mpeg/id3v1/id3v1genres.cpp \
		tag/taglib/taglib/mpeg/id3v1/id3v1tag.cpp \
		tag/taglib/taglib/mpeg/id3v2/frames/attachedpictureframe.cpp \
		tag/taglib/taglib/mpeg/id3v2/frames/commentsframe.cpp \
		tag/taglib/taglib/mpeg/id3v2/frames/relativevolumeframe.cpp \
		tag/taglib/taglib/mpeg/id3v2/frames/textidentificationframe.cpp \
		tag/taglib/taglib/mpeg/id3v2/frames/uniquefileidentifierframe.cpp \
		tag/taglib/taglib/mpeg/id3v2/frames/unknownframe.cpp \
		tag/taglib/taglib/mpeg/id3v2/frames/generalencapsulatedobjectframe.cpp \
		tag/taglib/taglib/mpeg/id3v2/id3v2extendedheader.cpp \
		tag/taglib/taglib/mpeg/id3v2/id3v2footer.cpp \
		tag/taglib/taglib/mpeg/id3v2/id3v2frame.cpp \
		tag/taglib/taglib/mpeg/id3v2/id3v2framefactory.cpp \
		tag/taglib/taglib/mpeg/id3v2/id3v2header.cpp \
		tag/taglib/taglib/mpeg/id3v2/id3v2synchdata.cpp \
		tag/taglib/taglib/mpeg/id3v2/id3v2tag.cpp \
		tag/taglib/taglib/mpeg/mpegfile.cpp \
		tag/taglib/taglib/mpeg/mpegheader.cpp \
		tag/taglib/taglib/mpeg/mpegproperties.cpp \
		tag/taglib/taglib/mpeg/xingheader.cpp \
		tag/taglib/taglib/ogg/flac/oggflacfile.cpp \
		tag/taglib/taglib/ogg/oggfile.cpp \
		tag/taglib/taglib/ogg/oggpage.cpp \
		tag/taglib/taglib/ogg/oggpageheader.cpp \
		tag/taglib/taglib/ogg/vorbis/vorbisfile.cpp \
		tag/taglib/taglib/ogg/vorbis/vorbisproperties.cpp \
		tag/taglib/taglib/ogg/xiphcomment.cpp \
		tag/taglib/taglib/tag.cpp \
		tag/taglib/taglib/toolkit/tbytevector.cpp \
		tag/taglib/taglib/toolkit/tbytevectorlist.cpp \
		tag/taglib/taglib/toolkit/tdebug.cpp \
		tag/taglib/taglib/toolkit/tfile.cpp \
		tag/taglib/taglib/toolkit/tstring.cpp \
		tag/taglib/taglib/toolkit/tstringlist.cpp \
		tag/taglib/taglib/toolkit/unicode.cpp \
		tag/taglib_addons/aac/aacfiletyperesolver.cpp \
		tag/taglib_addons/audible/audibleproperties.cpp \
		tag/taglib_addons/audible/audibletag.cpp \
		tag/taglib_addons/audible/taglib_audiblefile.cpp \
		tag/taglib_addons/audible/taglib_audiblefiletyperesolver.cpp \
		tag/taglib_addons/m4a/boxfactory.cpp \
		tag/taglib_addons/m4a/itunesalbbox.cpp \
		tag/taglib_addons/m4a/itunesartbox.cpp \
		tag/taglib_addons/m4a/itunescmtbox.cpp \
		tag/taglib_addons/m4a/itunescvrbox.cpp \
		tag/taglib_addons/m4a/itunesdatabox.cpp \
		tag/taglib_addons/m4a/itunesdaybox.cpp \
		tag/taglib_addons/m4a/itunesdiskbox.cpp \
		tag/taglib_addons/m4a/itunesgenbox.cpp \
		tag/taglib_addons/m4a/itunesgrpbox.cpp \
		tag/taglib_addons/m4a/itunesnambox.cpp \
		tag/taglib_addons/m4a/itunestmpobox.cpp \
		tag/taglib_addons/m4a/itunestrknbox.cpp \
		tag/taglib_addons/m4a/ituneswrtbox.cpp \
		tag/taglib_addons/m4a/mp4audioproperties.cpp \
		tag/taglib_addons/m4a/mp4audiosampleentry.cpp \
		tag/taglib_addons/m4a/mp4file.cpp \
		tag/taglib_addons/m4a/mp4fourcc.cpp \
		tag/taglib_addons/m4a/mp4hdlrbox.cpp \
		tag/taglib_addons/m4a/mp4ilstbox.cpp \
		tag/taglib_addons/m4a/mp4isobox.cpp \
		tag/taglib_addons/m4a/mp4isofullbox.cpp \
		tag/taglib_addons/m4a/mp4itunestag.cpp \
		tag/taglib_addons/m4a/mp4mdiabox.cpp \
		tag/taglib_addons/m4a/mp4metabox.cpp \
		tag/taglib_addons/m4a/mp4minfbox.cpp \
		tag/taglib_addons/m4a/mp4moovbox.cpp \
		tag/taglib_addons/m4a/mp4mvhdbox.cpp \
		tag/taglib_addons/m4a/mp4propsproxy.cpp \
		tag/taglib_addons/m4a/mp4sampleentry.cpp \
		tag/taglib_addons/m4a/mp4skipbox.cpp \
		tag/taglib_addons/m4a/mp4stblbox.cpp \
		tag/taglib_addons/m4a/mp4stsdbox.cpp \
		tag/taglib_addons/m4a/mp4tagsproxy.cpp \
		tag/taglib_addons/m4a/mp4trakbox.cpp \
		tag/taglib_addons/m4a/mp4udtabox.cpp \
		tag/taglib_addons/m4a/taglib_mp4filetyperesolver.cpp \
		tag/taglib_addons/rmff/rmff.cpp \
		tag/taglib_addons/rmff/taglib_realmediafile.cpp \
		tag/taglib_addons/rmff/taglib_realmediafiletyperesolver.cpp \
		tag/taglib_addons/speex/speexfile.cpp \
		tag/taglib_addons/speex/speexproperties.cpp \
		tag/taglib_addons/speex/taglib_speexfiletyperesolver.cpp \
		tag/taglib_addons/tplugins.cpp \
		tag/taglib_addons/trueaudio/taglib_trueaudiofiletyperesolver.cpp \
		tag/taglib_addons/trueaudio/ttafile.cpp \
		tag/taglib_addons/trueaudio/ttaproperties.cpp \
		tag/taglib_addons/wav/wavfile.cpp \
		tag/taglib_addons/wav/wavfiletyperesolver.cpp \
		tag/taglib_addons/wav/wavproperties.cpp \
		tag/taglib_addons/wavpack/taglib_wavpackfiletyperesolver.cpp \
		tag/taglib_addons/wavpack/wvfile.cpp \
		tag/taglib_addons/wavpack/wvproperties.cpp \
		tag/taglib_addons/wma/taglib_wmafiletyperesolver.cpp \
		tag/taglib_addons/wma/wmaattribute.cpp \
		tag/taglib_addons/wma/wmafile.cpp \
		tag/taglib_addons/wma/wmaproperties.cpp \
		tag/taglib_addons/wma/wmatag.cpp \
		kmdcodec/kmdcodec.cpp \		
		sqlite_source/sqlite3.c

TRANSLATIONS	= \
		quasar_ja.ts

MOC_DIR		= .moc
